@@ -52,11 +52,11 @@ public:
     Akonadi::Item mItem;
     Akonadi::Item mPrevItem;
     Akonadi::ItemFetchScope mFetchScope;
-    Akonadi::Monitor *mItemMonitor;
-    ItemEditorUi *mItemUi;
-    bool mIsCounterProposal;
+    Akonadi::Monitor *mItemMonitor = nullptr;
+    ItemEditorUi *mItemUi = nullptr;
+    bool mIsCounterProposal = false;
     EditorItemManager::SaveAction currentAction;
-    Akonadi::IncidenceChanger *mChanger;
+    Akonadi::IncidenceChanger *mChanger = nullptr;
 
 public:
     ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorItemManager *qq);
@@ -199,7 +199,7 @@ void ItemEditorPrivate::onModifyFinished(int, const Akonadi::Item &item,
         } else { // There's a collection move too.
             Akonadi::ItemMoveJob *moveJob = new Akonadi::ItemMoveJob(mItem,
                                                                      mItemUi->selectedCollection());
-            q->connect(moveJob, SIGNAL(result(KJob *)), SLOT(moveJobFinished(KJob *)));
+            q->connect(moveJob, SIGNAL(result(KJob*)), SLOT(moveJobFinished(KJob*)));
         }
     } else if (resultCode == Akonadi::IncidenceChanger::ResultCodeUserCanceled) {
         Q_EMIT q->itemSaveFailed(EditorItemManager::Modify, QString());
@@ -230,6 +230,7 @@ void ItemEditorPrivate::setupMonitor()
     // Q_Q(EditorItemManager);
     delete mItemMonitor;
     mItemMonitor = new Akonadi::Monitor;
+    mItemMonitor->setObjectName(QStringLiteral("EditorItemManagerMonitor"));
     mItemMonitor->ignoreSession(Akonadi::Session::defaultSession());
     mItemMonitor->itemFetchScope().fetchFullPayload();
     if (mItem.isValid()) {
@@ -309,10 +310,9 @@ Akonadi::Item EditorItemManager::item(ItemState state) const
                                          << "; and haPayload is " << d->mPrevItem.hasPayload();
         }
         break;
-    default:
-        qCDebug(INCIDENCEEDITOR_LOG) << "state = " << state;
-        Q_ASSERT_X(false, "EditorItemManager::item", "Unknown enum value");
     }
+    qCDebug(INCIDENCEEDITOR_LOG) << "state = " << state;
+    Q_ASSERT_X(false, "EditorItemManager::item", "Unknown enum value");
     return Akonadi::Item();
 }
 
@@ -323,7 +323,7 @@ void EditorItemManager::load(const Akonadi::Item &item)
     //We fetch anyways to make sure we have everything required including tags
     Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
     job->setFetchScope(d->mFetchScope);
-    connect(job, SIGNAL(result(KJob *)), SLOT(itemFetchResult(KJob *)));
+    connect(job, SIGNAL(result(KJob*)), SLOT(itemFetchResult(KJob*)));
 }
 
 void EditorItemManager::save()
@@ -371,7 +371,7 @@ void EditorItemManager::save()
             } else {
                 Akonadi::ItemMoveJob *itemMoveJob
                     = new Akonadi::ItemMoveJob(d->mItem, d->mItemUi->selectedCollection());
-                connect(itemMoveJob, SIGNAL(result(KJob *)), SLOT(itemMoveResult(KJob *)));
+                connect(itemMoveJob, SIGNAL(result(KJob*)), SLOT(itemMoveResult(KJob*)));
             }
         }
     } else { // An invalid item. Means we're creating.
